# ARGE Consumption Data Client
Python Client zum Abruf unterjähriger Verbrauchsinformationen über die *ARGE consumption-data API*.

## Hintergrund

Im Rahmen der [EED](https://de.wikipedia.org/wiki/Richtlinie_2012/27/EU_(Energieeffizienz-Richtlinie)) veröffentlicht die [ARGE HeiWaKo](https://arge-heiwako.de/) einen Webservice mit dem monatliche Verbrauchsdaten auf Nutzeinheitenebene vom Wärmedienstunternehmen abgerufen werden können.

Dieser Service solle es der Wohnungswirtschaft ermöglichen, Nutzern/Bewohnern eine unterjährige Verbrauchsinformation im Rahmen der EED in eigenen IT-Systemen bereitzustellen.

Mehr Infos hier: [ARGE HEIWAKO: Datenaustausch](https://arge-heiwako.de/veroeffentlichungen/datenaustausch/)
